@@ -2,8 +2,8 @@
 
 __description__ = 'Analyze OLE files (Compound Binary Files)'
 __author__ = 'Didier Stevens'
-__version__ = '0.0.33'
-__date__ = '2018/02/18'
+__version__ = '0.0.37'
+__date__ = '2018/08/04'
 
 """
 
@@ -73,6 +73,11 @@ History:
   2017/12/13: 0.0.31 corrected man
   2017/12/16: 0.0.32 added indexQuiet to cPlugin
   2018/02/18: 0.0.33 added option -j
+  2018/05/06: 0.0.34 -s is more userfriendly
+  2018/07/01: 0.0.35 rename option --json to --jsonoutput
+  2018/07/01: fix for json output with OOXML files
+  2018/07/07: 0.0.36: updated to version 2 of jsonoutput
+  2018/08/04: 0.0.37 added option --vbadecompressskipattributes
 
 Todo:
 """
@@ -244,6 +249,8 @@ Attribute VB_Customizable = True
 If the VBA code contains other statements than Attribute or Options statements, then the indicator is a upper case letter M.
 This M/m indicator allows you to focus first on interesting VBA macros.
 
+To decompress the macros and skip the initial attributes, use option --vbadecompressskipattributes.
+
 When compressed VBA code is corrupted, the status indicatore will be E (error).
 C:\Demo>oledump.py Book2-vba.xls
   1:       109 '\\x01CompObj'
@@ -766,12 +773,22 @@ def SearchAndDecompressSub(data):
         compressedData = data[position - 3:]
     return Decompress(compressedData)
 
-def SearchAndDecompress(data, ifError='Error: unable to decompress\n'):
+def SkipAttributes(text):
+    oAttribute = re.compile('^Attribute VB_.+? = [^\n]+\n')
+    while True:
+        oMatch = oAttribute.match(text)
+        if oMatch == None:
+            break
+        text = text[len(oMatch.group()):]
+    return text
+
+def SearchAndDecompress(data, ifError='Error: unable to decompress\n', skipAttributes=False):
     result, decompress = SearchAndDecompressSub(data)
-    if result:
-        return decompress
-    elif ifError == None:
-        return decompress
+    if result or ifError == None:
+        if skipAttributes:
+            return SkipAttributes(decompress)
+        else:
+            return decompress
     else:
         return ifError
 
@@ -1435,13 +1452,13 @@ def OLESub(ole, prefix, rules, options):
                     print(' %s: %s' % (attribute, value))
         return returnCode
 
-    if options.json:
+    if options.jsonoutput:
         object = []
         counter = 1
         for orphan, fname, entry_type, stream in OLEGetStreams(ole):
-            object.append({'id': counter, 'name': PrintableName(fname), 'content': binascii.b2a_base64(stream)})
+            object.append({'id': counter, 'name': PrintableName(fname), 'content': binascii.b2a_base64(stream).strip('\n')})
             counter += 1
-        print(json.dumps({'version': 1, 'fields': ['id', 'name', 'content'], 'items': object}))
+        print(json.dumps({'version': 2, 'id': 'didierstevens.com', 'type': 'content', 'fields': ['id', 'name', 'content'], 'items': object}))
         return
 
     if options.select == '':
@@ -1556,6 +1573,11 @@ def OLESub(ole, prefix, rules, options):
                 DumpFunction = lambda x: SearchAndDecompress(x, '')
             else:
                 DumpFunction = SearchAndDecompress
+        elif options.vbadecompressskipattributes:
+            if options.select == 'a':
+                DumpFunction = lambda x: SearchAndDecompress(x, '', True)
+            else:
+                DumpFunction = lambda x: SearchAndDecompress(x, skipAttributes=True)
         elif options.vbadecompresscorrupt:
             DumpFunction = lambda x: SearchAndDecompress(x, None)
         elif options.extract:
@@ -1571,7 +1593,7 @@ def OLESub(ole, prefix, rules, options):
             DumpFunction = HexAsciiDump
         counter = 1
         for orphan, fname, entry_type, stream in OLEGetStreams(ole):
-            if options.select == 'a' or ('%s%d' % (prefix, counter)) == options.select:
+            if options.select == 'a' or ('%s%d' % (prefix, counter)) == options.select or prefix == 'A' and str(counter) == options.select:
                 StdoutWriteChunked(DumpFunction(DecompressFunction(DecodeFunction(decoders, options, CutData(stream, options.cut)))))
                 if options.select != 'a':
                     break
@@ -1632,9 +1654,9 @@ def OLEDump(filename, options):
             data = File2String(filename)
         if options.vbadecompress:
             if options.vbadecompresscorrupt:
-                vba = SearchAndDecompress(data, None)
+                vba = SearchAndDecompress(data, None, skipAttributes=options.vbadecompressskipattributes)
             else:
-                vba = SearchAndDecompress(data)
+                vba = SearchAndDecompress(data, skipAttributes=options.vbadecompressskipattributes)
             if options.plugins == '':
                 print(vba)
                 return returnCode
@@ -1709,7 +1731,7 @@ def OLEDump(filename, options):
                 letter = chr(ord('A') + counter)
                 counter += 1
                 if options.select == '':
-                    if not options.quiet:
+                    if not options.quiet and not options.jsonoutput:
                         print('%s: %s' % (letter, info.filename))
                 ole = olefile.OleFileIO(cStringIO.StringIO(content))
                 returnCode = OLESub(ole, letter, rules, options)
@@ -1775,6 +1797,7 @@ def Main():
     oParser.add_option('-a', '--asciidump', action='store_true', default=False, help='perform ascii dump')
     oParser.add_option('-S', '--strings', action='store_true', default=False, help='perform strings dump')
     oParser.add_option('-v', '--vbadecompress', action='store_true', default=False, help='VBA decompression')
+    oParser.add_option('--vbadecompressskipattributes', action='store_true', default=False, help='VBA decompression, skipping initial attributes')
     oParser.add_option('--vbadecompresscorrupt', action='store_true', default=False, help='VBA decompression, display beginning if corrupted')
     oParser.add_option('-r', '--raw', action='store_true', default=False, help='read raw file (use with options -v or -p')
     oParser.add_option('-t', '--translate', type=str, default='', help='string translation, like utf16 or .decode("utf8")')
@@ -1795,7 +1818,7 @@ def Main():
     oParser.add_option('-V', '--verbose', action='store_true', default=False, help='verbose output with decoder errors')
     oParser.add_option('-C', '--cut', type=str, default='', help='cut data')
     oParser.add_option('-E', '--extra', type=str, default='', help='add extra info (environment variable: OLEDUMP_EXTRA)')
-    oParser.add_option('-j', '--json', action='store_true', default=False, help='produce json output')
+    oParser.add_option('-j', '--jsonoutput', action='store_true', default=False, help='produce json output')
     (options, args) = oParser.parse_args()
 
     if options.man:
